@@ -254,7 +254,7 @@ class RequestHandler(tornado.web.RequestHandler):
         self.browser_type = self.application.settings.get('browser_default_type', 'mobile')
         self.auth_callback = self.application.settings.get('auth_callback', NotImplemented)
 
-        # self.db = self.application.settings.get('db', NotImplemented)
+        self.db = self.application.settings.get('db', NotImplemented)
         # self.acct_db = self.application.settings.get('acct_db', NotImplemented)
 
         self.cache_db = self.application.settings.get('cache_db', NotImplemented)
@@ -276,7 +276,7 @@ class RequestHandler(tornado.web.RequestHandler):
         #     self.smtp = None
 
         self.smtp=None
-        self.db = None
+        # self.db = None
         self.acct_db = None
         # self.cache_db=None
         # self.session=None
